## Summary

Brief description of the changes.

## Changes

- ...
- ...

## Type of Change

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)

## Testing

- [ ] All existing tests pass (`python -m pytest tests/ -x -q --tb=short`)
- [ ] New tests added for new functionality
- [ ] Linting passes (`ruff check src/ tests/ --select=F821,F811`)

## Screenshots

<!-- If this changes the Web UI or Control Center, please include before/after screenshots. -->

## Breaking Changes

<!-- If this is a breaking change, describe what breaks and how users should migrate. -->

## Related Issues

Closes #...
